@@ -1,4 +1,4 @@
-import argparse, hashlib, operator, shlex, shutil
+import argparse, operator, shlex, shutil
 from pathlib import Path
 from typing import Dict
 
@@ -65,7 +65,7 @@ def fs_actions_usage(action, default_db):
         library {action} -u duration -p -s 'title'
 
         Print an aggregate report of deleted media
-        library {action} -w is_deleted=1 -p a
+        library {action} -w is_deleted=1 -p=a
         ╒═══════════╤══════════════╤═════════╤═════════╕
         │ path      │ duration     │ size    │   count │
         ╞═══════════╪══════════════╪═════════╪═════════╡
@@ -76,16 +76,19 @@ def fs_actions_usage(action, default_db):
         Total duration: 14 days, 23 hours and 42 minutes
 
         Print an aggregate report of media that has no duration information (likely corrupt media)
-        library {action} -w 'duration is null' -p a
+        library {action} -w 'duration is null' -p=a
 
-        Print a list of videos which have below 1280px resolution
-        library wt -w 'width<1280' -p f
+        Print a list of filenames which have below 1280px resolution
+        library wt -w 'width<1280' -p=f
+
+        Print media you have partially viewed with mpv
+        library {action} -p=v
 
         View how much time you have {action}ed
-        library {action} -w play_count'>'0 -p a
+        library {action} -w play_count'>'0 -p=a
 
         See how much video you have
-        library wt video.db -p a
+        library wt video.db -p=a
         ╒═══════════╤═════════╤═════════╤═════════╕
         │ path      │   hours │ size    │   count │
         ╞═══════════╪═════════╪═════════╪═════════╡
@@ -132,21 +135,22 @@ def fs_actions_usage(action, default_db):
         Video files have less consistent metadata and so only paths are included in search.
         library {action} --include happy  # only matches will be included
         library {action} -s happy         # equivalent
-        library {action} --exclude sad   # matches will be excluded
-        library {action} -E sad          # equivalent
+        library {action} --exclude sad    # matches will be excluded
+        library {action} -E sad           # equivalent
 
         Search only the path column
         library {action} -O -s 'path : mad max'
+        library {action} -O -s 'path : "mad max"' # add "quotes" to be more strict
 
         Double spaces are parsed as one space
         -s '  ost'        # will match OST and not ghost
         -s toy story      # will match '/folder/toy/something/story.mp3'
-        -s 'toy  story'    # will match more strictly '/folder/toy story.mp3'
+        -s 'toy  story'   # will match more strictly '/folder/toy story.mp3'
 
     Constrain media by arbitrary SQL expressions:
         library {action} --where audio_count = 2  # media which have two audio tracks
         library {action} -w "language = 'eng'"    # media which have an English language tag
-                                               (this could be audio _or_ subtitle)
+                                                    (this could be audio _or_ subtitle)
         library {action} -w subtitle_count=0      # media that doesn't have subtitles
 
     Constrain media to duration (in minutes):
@@ -631,16 +635,6 @@ def construct_fs_query(args):
     return query, bindings
 
 
-def mpv_enrich(args, media):
-    for m in media:
-        md5 = hashlib.md5(m["path"].encode("utf-8")).hexdigest().upper()
-        if Path(args.watch_later_directory, md5).exists():
-            m["time_partial_first"] = int(Path(args.watch_later_directory, md5).stat().st_ctime)
-            m["time_partial_last"] = int(Path(args.watch_later_directory, md5).stat().st_mtime)
-
-    return sorted(media, key=lambda m: m.get("time_partial_first") or 0, reverse=True)
-
-
 def process_playqueue(args, construct_query=construct_fs_query):
     args.db = db.connect(args)
     query, bindings = construct_query(args)
@@ -654,8 +648,8 @@ def process_playqueue(args, construct_query=construct_fs_query):
         print("No media found")
         exit(2)
 
-    if shutil.which("mpv") and Path(args.watch_later_directory).exists():
-        media = mpv_enrich(args, media)
+    if Path(args.watch_later_directory).exists():
+        media = utils.mpv_enrich(args, media)
 
     args.is_mounted = paths.is_mounted(list(map(operator.itemgetter("path"), media)), args.shallow_organize)
 
