@@ -17,8 +17,8 @@ def parse_args(action):
 
     parser.add_argument("--verbose", "-v", action="count", default=0)
     args = parser.parse_args()
-
-    args.mpv = MPV(start_mpv=False, ipc_socket=args.mpv_socket)
+    if os.path.exists(args.mpv_socket):
+        args.mpv = MPV(start_mpv=False, ipc_socket=args.mpv_socket)
 
     log.info(utils.dict_filter_bool(args.__dict__))
 
@@ -33,19 +33,26 @@ def _now_playing(args):
     log.info(media)
     if None not in media.values():
         log.warning("Both `catt` and `mpv` playback files found!")
+
     return media
 
 
+def print_now_playing(playing, source):
+    if playing[source].startswith("http"):
+        print(f"[{source}]:", cmd("ffprobe", "-hide_banner", "-loglevel", "info", playing[source]).stderr)
+    else:
+        print(f"[{source}]:", playing[source])
+
+
 def playback_now():
     args = parse_args("now")
     playing = _now_playing(args)
 
     if playing["mpv"]:
-        print("[mpv]:", playing["mpv"])
+        print_now_playing(playing, "mpv")
+        args.mpv.terminate()
     if playing["catt"]:
-        print("[catt]:", playing["catt"])
-
-    args.mpv.terminate()
+        print_now_playing(playing, "catt")
 
 
 def catt_stop(args):
@@ -68,10 +75,11 @@ def playback_stop():
     playing = _now_playing(args)
     if playing["mpv"]:
         args.mpv.command("loadfile", "/dev/null")  # make mpv exit with code 3
-    else:
-        [kill_process(s) for s in ["python.*xklb", "bin/lb", "bin/library", "mpv"]]
+    # else:
+    #     [kill_process(s) for s in ["python.*xklb", "bin/lb", "bin/library", "mpv"]]
 
     if playing["catt"]:
+        kill_process("catt")
         catt_stop(args)
 
     Path(paths.CAST_NOW_PLAYING).unlink(missing_ok=True)
@@ -83,10 +91,14 @@ def playback_next():
 
     playing = _now_playing(args)
 
-    if args.delete:
-        # TODO: figure out if catt or mpv is stale
-        for media in playing.values():
-            Path(media).unlink()
+    # TODO: figure out if catt or mpv is stale
+    if playing["catt"]:
+        Path(paths.CAST_NOW_PLAYING).unlink(missing_ok=True)
+        catt_stop(args)
+        if args.delete:
+            Path(playing["catt"]).unlink(missing_ok=True)
 
-    catt_stop(args)
-    args.mpv.command("playlist_next", "force")
+    if playing["mpv"]:
+        args.mpv.command("playlist_next", "force")
+        if args.delete:
+            Path(playing["mpv"]).unlink(missing_ok=True)
